@@ -23,7 +23,7 @@ import struct
 sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__),
                                                  "..")))
 
-from pasaffe_lib.figaroxml import FigaroXML
+from pasaffe_lib.figaroxml import FigaroXML  # noqa: E402
 
 
 class TestFigaroXML079(unittest.TestCase):
