@@ -18,15 +18,14 @@
 import sys
 import os.path
 import unittest
-import time
 sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__),
                                                  "..")))
 
-from pasaffe_lib.helpers import folder_list_to_field
-from pasaffe_lib.helpers import field_to_folder_list
-from pasaffe_lib.helpers import folder_list_to_path
-from pasaffe_lib.helpers import folder_path_to_list
-from pasaffe_lib.helpers import PathEntry
+from pasaffe_lib.helpers import folder_list_to_field  # noqa: E402
+from pasaffe_lib.helpers import field_to_folder_list  # noqa: E402
+from pasaffe_lib.helpers import folder_list_to_path  # noqa: E402
+from pasaffe_lib.helpers import folder_path_to_list  # noqa: E402
+from pasaffe_lib.helpers import PathEntry  # noqa: E402
 
 
 class TestHelpers(unittest.TestCase):
@@ -34,16 +33,20 @@ class TestHelpers(unittest.TestCase):
 
         folder_list = [[[], ""],
                        [["foldera"], "foldera"],
-                       [["folder.a"], "folder\.a"],
-                       [["foldera."], "foldera\."],
-                       [[".foldera"], "\.foldera"],
-                       [["foldera.", "folderb."], "foldera\..folderb\."],
+                       [["folder.a"], "folder\.a"],  # noqa: W605
+                       [["foldera."], "foldera\."],  # noqa: W605
+                       [[".foldera"], "\.foldera"],  # noqa: W605
+                       [["foldera.", "folderb."],
+                         "foldera\..folderb\."],  # noqa: W605
                        [["foldera", "folderb"], "foldera.folderb"],
-                       [["folder.a", "folderb"], "folder\.a.folderb"],
-                       [["foldera", "folder.b"], "foldera.folder\.b"],
-                       [["folder.a", "folder.b"], "folder\.a.folder\.b"],
+                       [["folder.a", "folderb"],
+                         "folder\.a.folderb"],  # noqa: W605
+                       [["foldera", "folder.b"],
+                         "foldera.folder\.b"],  # noqa: W605
+                       [["folder.a", "folder.b"],
+                         "folder\.a.folder\.b"],  # noqa: W605
                        [["folder.a", "folder.b", "folder.c"],
-                           "folder\.a.folder\.b.folder\.c"]]
+                           "folder\.a.folder\.b.folder\.c"]]  # noqa: W605
 
         for (folder, field) in folder_list:
             self.assertEqual(folder_list_to_field(folder), field)
@@ -52,13 +55,16 @@ class TestHelpers(unittest.TestCase):
 
         folder_list = [["", []],
                        ["foldera", ["foldera"]],
-                       ["folder\.a", ["folder.a"]],
-                       ["foldera\.", ["foldera."]],
-                       ["\.foldera", [".foldera"]],
-                       ["foldera\..folderb\.", ["foldera.", "folderb."]],
+                       ["folder\.a", ["folder.a"]],  # noqa: W605
+                       ["foldera\.", ["foldera."]],  # noqa: W605
+                       ["\.foldera", [".foldera"]],  # noqa: W605
+                       ["foldera\..folderb\.",
+                        ["foldera.", "folderb."]],  # noqa: W605
                        ["foldera.folderb", ["foldera", "folderb"]],
-                       ["folder\.a.folderb", ["folder.a", "folderb"]],
-                       ["foldera.folder\.b", ["foldera", "folder.b"]],
+                       ["folder\.a.folderb",
+                        ["folder.a", "folderb"]],  # noqa: W605
+                       ["foldera.folder\.b",
+                        ["foldera", "folder.b"]],  # noqa: W605
                        ["folder\.a.folder\.b", ["folder.a", "folder.b"]],
                        ["folder\.a.folder\.b.folder\.c",
                            ["folder.a", "folder.b", "folder.c"]]]
@@ -71,16 +77,18 @@ class TestHelpers(unittest.TestCase):
         folder_list = [[[], "/"],
                        [["foldera"], "/foldera/"],
                        [["folder.a"], "/folder.a/"],
-                       [["folder/a"], "/folder\/a/"],
+                       [["folder/a"], "/folder\/a/"],  # noqa: W605
                        [["foldera."], "/foldera./"],
-                       [["foldera/"], "/foldera\//"],
+                       [["foldera/"], "/foldera\//"],  # noqa: W605
                        [[".foldera"], "/.foldera/"],
-                       [["/foldera"], "/\/foldera/"],
+                       [["/foldera"], "/\/foldera/"],  # noqa: W605
                        [["foldera.", "folderb."], "/foldera./folderb./"],
-                       [["foldera/", "folderb/"], "/foldera\//folderb\//"],
+                       [["foldera/", "folderb/"],
+                         "/foldera\//folderb\//"],  # noqa: W605
                        [["foldera", "folderb"], "/foldera/folderb/"],
                        [["folder.a", "folderb"], "/folder.a/folderb/"],
-                       [["folder/a", "folderb"], "/folder\/a/folderb/"],
+                       [["folder/a", "folderb"],
+                         "/folder\/a/folderb/"],  # noqa: W605
                        [["foldera", "folder.b"], "/foldera/folder.b/"],
                        [["foldera", "folder/b"], "/foldera/folder\/b/"],
                        [["folder.a", "folder.b"], "/folder.a/folder.b/"],
@@ -98,13 +106,14 @@ class TestHelpers(unittest.TestCase):
         folder_list = [["/", []],
                        ["/foldera/", ["foldera"]],
                        ["/folder.a/", ["folder.a"]],
-                       ["/folder\/a/", ["folder/a"]],
+                       ["/folder\/a/", ["folder/a"]],  # noqa: W605
                        ["/foldera./", ["foldera."]],
-                       ["/foldera\//", ["foldera/"]],
+                       ["/foldera\//", ["foldera/"]],  # noqa: W605
                        ["/.foldera/", [".foldera"]],
-                       ["/\/foldera/", ["/foldera"]],
+                       ["/\/foldera/", ["/foldera"]],  # noqa: W605
                        ["/foldera./folderb./", ["foldera.", "folderb."]],
-                       ["/foldera\//folderb\//", ["foldera/", "folderb/"]],
+                       ["/foldera\//folderb\//",
+                        ["foldera/", "folderb/"]],  # noqa: W605
                        ["/foldera/folderb/", ["foldera", "folderb"]],
                        ["/folder.a/folderb/", ["folder.a", "folderb"]],
                        ["/folder\/a/folderb/", ["folder/a", "folderb"]],
@@ -220,5 +229,6 @@ class TestHelpers(unittest.TestCase):
         for i in range(len(test_entries)):
             self.assertEqual(sorted_entries[i], results[i])
 
+
 if __name__ == '__main__':
     unittest.main()
