@@ -18,32 +18,30 @@
 import sys
 import os.path
 import unittest
-import time
-import struct
 import tempfile
 import shutil
 import subprocess
 sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__),
                                                  "..")))
 
-from pasaffe_lib.keepassx import KeePassX
-from pasaffe_lib.readdb import PassSafeFile
-from test_keepass2_224 import TestKeePass2224
+from pasaffe_lib.readdb import PassSafeFile  # noqa: E402
+from test_keepass2_224 import TestKeePass2224  # noqa: E402
 
 
 class TestKeePass2Import(TestKeePass2224):
     def setUp(self):
         self.tempdir = tempfile.mkdtemp()
         self.imported_db = os.path.join(self.tempdir, 'imported.psafe3')
-        rc = subprocess.call(['bin/pasaffe-import-keepassx', '-q',
-                              '-f', './tests/databases/keepass2-224.xml',
-                              '-d', self.imported_db,
-                              '-y', '-m', 'pasaffe'])
+        subprocess.call(['bin/pasaffe-import-keepassx', '-q',
+                         '-f', './tests/databases/keepass2-224.xml',
+                         '-d', self.imported_db,
+                         '-y', '-m', 'pasaffe'])
         self.passfile = PassSafeFile(self.imported_db, 'pasaffe')
 
     def tearDown(self):
         if os.path.exists(self.tempdir):
             shutil.rmtree(self.tempdir)
 
+
 if __name__ == '__main__':
     unittest.main()
