@@ -19,12 +19,12 @@ import sys
 import os.path
 import unittest
 import time
-from binascii import hexlify, unhexlify
+from binascii import hexlify
 
 sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__),
                                     "..")))
 
-from pasaffe_lib.readdb import PassSafeFile
+from pasaffe_lib.readdb import PassSafeFile  # noqa: E402
 
 
 class TestReadDB(unittest.TestCase):
@@ -35,12 +35,14 @@ class TestReadDB(unittest.TestCase):
 
         folder_list = [[[], ""],
                        [["foldera"], "foldera"],
-                       [["folder.a"], "folder\.a"],
-                       [["foldera."], "foldera\."],
-                       [[".foldera"], "\.foldera"],
-                       [["foldera.", "folderb."], "foldera\..folderb\."],
+                       [["folder.a"], "folder\.a"],  # noqa: W605
+                       [["foldera."], "foldera\."],  # noqa: W605
+                       [[".foldera"], "\.foldera"],  # noqa: W605
+                       [["foldera.", "folderb."],
+                         "foldera\..folderb\."],  # noqa: W605
                        [["foldera", "folderb"], "foldera.folderb"],
-                       [["folder.a", "folderb"], "folder\.a.folderb"],
+                       [["folder.a", "folderb"],
+                         "folder\.a.folderb"],  # noqa: W605
                        [["foldera", "folder.b"], "foldera.folder\.b"],
                        [["folder.a", "folder.b"], "folder\.a.folder\.b"],
                        [["folder.a", "folder.b", "folder.c"],
@@ -59,10 +61,11 @@ class TestReadDB(unittest.TestCase):
 
         folder_list = [["", []],
                        ["foldera", ["foldera"]],
-                       ["folder\.a", ["folder.a"]],
-                       ["foldera\.", ["foldera."]],
-                       ["\.foldera", [".foldera"]],
-                       ["foldera\..folderb\.", ["foldera.", "folderb."]],
+                       ["folder\.a", ["folder.a"]],  # noqa: W605
+                       ["foldera\.", ["foldera."]],  # noqa: W605
+                       ["\.foldera", [".foldera"]],  # noqa: W605
+                       ["foldera\..folderb\.",
+                        ["foldera.", "folderb."]],  # noqa: W605
                        ["foldera.folderb", ["foldera", "folderb"]],
                        ["folder\.a.folderb", ["folder.a", "folderb"]],
                        ["foldera.folder\.b", ["foldera", "folder.b"]],
@@ -305,8 +308,6 @@ class TestReadDB(unittest.TestCase):
                          'folderA.folderB',
                          'folderA.folderB.folderC']
 
-        folder = ['folderA', 'folderB', 'folderC']
-
         # pass by value
         self.passfile.empty_folders = folder_fields[:]
 
@@ -358,7 +359,7 @@ class TestReadDB(unittest.TestCase):
         folderB = ['OtherFolderA', 'OtherFolderB']
 
         uuid_hex_B = self.passfile.new_entry()
-        uuid_hex_C = self.passfile.new_entry()
+        self.passfile.new_entry()
         self.passfile.update_folder_list(uuid_hex_B, folderB)
 
         all_folders = folder_list + [folderB]
@@ -700,5 +701,6 @@ class TestReadDB(unittest.TestCase):
         self.assertNotEqual(uuid5, None)
         self.assertEqual(uuid3, uuid5)
 
+
 if __name__ == '__main__':
     unittest.main()
